==> ucloud-ko-fileupload-3.0.5.tgz: package/src/coop-fileupload/index.js <==
import ko from "knockout";
import _ from "lodashmix";
import { initVM, queryFile, clearFile, initTempId } from './function';
let tempBuyerTenant = null;
function getXtDomainUrl (buyerTenant) {
  if(tempBuyerTenant == buyerTenant){
    return;
  }
  tempBuyerTenant = buyerTenant
  $.ajax({
    type: 'GET',
    async: false,
    url: `/yonbip-cpu-portal/tenant/dcWorkbenchUrl/${buyerTenant}`,
    success: function (result) {
      let {data, code} = result
      if(code == '200')
      window.sessionStorage.setItem('XtDomainUrl', data + 'iuap-apcom-file')
    }
  });
}
// 协同云附件直接可跨租户，所以不需要传enterpriseId或者tenantId
function entry(params) {
  window.creatCoopUrl()
  this.isCooper = true
  const config = {
    inTable: false
  };
  if (!params) {
    params = {};
  }
  this.tempId = params.tempId || ko.observable(initTempId())
  if (!params.coopParams) {
    params.coopParams = {};
  }
  if(params.enableBuyerTenant){//根据这个参数判断是否需要进行附件地址处理
    // 判断url是否有ycCrossTenantBuyerTenant
    let urlTenantBuyerTenant = function () {
      return new Promise((reslove, reject)=>{
          if(new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')){
              getXtDomainUrl (new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant'))
              params.cloneYcCrossTenantBuyerTenant = new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')
              reslove(true)
          }else{
            reslove(true)
          }
      })
    } 
    let crossTenantBuyerTenant =  function () {
      return new Promise((reslove, reject)=>{
        if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant()){
          getXtDomainUrl (params.ycCrossTenantBuyerTenant())
          params.cloneYcCrossTenantBuyerTenant = params.ycCrossTenantBuyerTenant()
          reslove(true)
        }else if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant.subscribe ){
          params.ycCrossTenantBuyerTenant.subscribe(function (value) {
            // console.log('%c 🍐 value: ', 'font-size:20px;background-color: #33A5FF;color:#fff;', value);
            getXtDomainUrl (value)
            params.cloneYcCrossTenantBuyerTenant = value
            reslove(true)
          })
        }else{
          reslove(true)
        }
      })
    }
    Promise.all([urlTenantBuyerTenant(), crossTenantBuyerTenant()]).then(result => {
      let res = result.every(item => {return item == true})
      if(!res){
        window.sessionStorage.removeItem('XtDomainUrl')
      } 
      initFile(this, params, config)
    })
  }else{
    window.sessionStorage.removeItem('XtDomainUrl')
    initFile(this, params, config)
  }
}
function initFile (that, params, config) {
  initVM.call(that, params, config);
  let id = config[config.type]();
  if (id && id != '' && id != 0) {
    queryFile(that, params, config);
  }else if(params.noclearFile) {
    console.log('noclearFile');
  }else{
    clearFile(that, params, config);
  }
}
entry.prototype.dispose = function (params) {
  this.readonly._subscription && this.readonly._subscription.dispose()
}
var fn2 =  function (params, componentInfo) {
    params.$el = componentInfo.element;
    params.$templateNodes = componentInfo.templateNodes;
    return new entry(params);
}

var init = {
  createViewModel: fn2
};

export const entryCooper = entry
export default init;

==> ucloud-ko-fileupload-4.0.5.tgz: package/src/coop-fileupload/index.js <==
import ko from "knockout";
import _ from "lodashmix";
import { initVM, queryFile, clearFile, initTempId,processingUrl} from './function';
let tempBuyerTenant = null;
function getXtDomainUrl (buyerTenant) {
  if(tempBuyerTenant == buyerTenant){
    return;
  }
  tempBuyerTenant = buyerTenant
  $.ajax({
    type: 'GET',
    async: false,
    url: `/yonbip-cpu-portal/tenant/dcWorkbenchUrl/${buyerTenant}`,
    success: function (result) {
      let {data, code} = result
      if(code == '200')
      if(data.endsWith('/')){
        data = data.slice(0, -1)
      }
      data = processingUrl(window.location.origin,data)
      window.sessionStorage.setItem('XtDomainUrl', data + '/iuap-apcom-file')
    }
  });
}
// 协同云附件直接可跨租户，所以不需要传enterpriseId或者tenantId
function entry(params) {
  window.creatCoopUrl()
  this.isCooper = true
  const config = {
    inTable: false
  };
  if (!params) {
    params = {};
  }
  this.tempId = params.tempId || ko.observable(initTempId())
  if (!params.coopParams) {
    params.coopParams = {};
  }
  if(params.enableBuyerTenant){//根据这个参数判断是否需要进行附件地址处理
    // 判断url是否有ycCrossTenantBuyerTenant
    let urlTenantBuyerTenant = function () {
      return new Promise((reslove, reject)=>{
          if(new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')){
              getXtDomainUrl (new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant'))
              params.cloneYcCrossTenantBuyerTenant = new URLSearchParams(window.location.href).get('ycCrossTenantBuyerTenant')
              reslove(true)
          }else{
            reslove(true)
          }
      })
    } 
    let crossTenantBuyerTenant =  function () {
      return new Promise((reslove, reject)=>{
        if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant()){
          getXtDomainUrl (params.ycCrossTenantBuyerTenant())
          params.cloneYcCrossTenantBuyerTenant = params.ycCrossTenantBuyerTenant()
          reslove(true)
        }else if(params.ycCrossTenantBuyerTenant && params.ycCrossTenantBuyerTenant.subscribe ){
          params.ycCrossTenantBuyerTenant.subscribe(function (value) {
            // console.log('%c 🍐 value: ', 'font-size:20px;background-color: #33A5FF;color:#fff;', value);
            getXtDomainUrl (value)
            params.cloneYcCrossTenantBuyerTenant = value
            reslove(true)
          })
        }else{
          reslove(true)
        }
      })
    }
    Promise.all([urlTenantBuyerTenant(), crossTenantBuyerTenant()]).then(result => {
      let res = result.every(item => {return item == true})
      if(!res){
        window.sessionStorage.removeItem('XtDomainUrl')
      } 
      initFile(this, params, config)
    })
  }else{
    window.sessionStorage.removeItem('XtDomainUrl')
    initFile(this, params, config)
  }
}
function initFile (that, params, config) {
  initVM.call(that, params, config);
  let id = config[config.type]();
  if (id && id != '' && id != 0) {
    queryFile(that, params, config);
  }else if(params.noclearFile) {
    console.log('noclearFile');
  }else{
    clearFile(that, params, config);
  }
}
entry.prototype.dispose = function (params) {
  this.readonly._subscription && this.readonly._subscription.dispose()
}
var fn2 =  function (params, componentInfo) {
    params.$el = componentInfo.element;
    params.$templateNodes = componentInfo.templateNodes;
    return new entry(params);
}

var init = {
  createViewModel: fn2
};

export const entryCooper = entry
export default init;
